/* File:        $Id: ChecksumArchiveServer.java 2266 2012-02-15 17:28:23Z svc $
 * Revision:    $Revision: 2266 $
 * Author:      $Author: svc $
 * Date:        $Date: 2012-02-15 18:28:23 +0100 (Wed, 15 Feb 2012) $
 *
 * The Netarchive Suite - Software to harvest and preserve websites
 * Copyright 2004-2012 The Royal Danish Library, the Danish State and
 * University Library, the National Library of France and the Austrian
 * National Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 
 *  USA
 */
package dk.netarkivet.archive.checksum.distribute;

import dk.netarkivet.common.distribute.ChannelID;
import dk.netarkivet.common.distribute.JMSConnection;
import dk.netarkivet.common.utils.CleanupIF;
import dk.netarkivet.archive.bitarchive.distribute.UploadMessage;
import dk.netarkivet.archive.distribute.ArchiveMessageHandler;

/**
 * Any subclass must be invoked through a method called 'getInstance'.
 */
public abstract class ChecksumArchiveServer extends ArchiveMessageHandler 
        implements CleanupIF {
    
    /**
     * The JMS connection.
     */
    protected JMSConnection jmsCon;
    
    /**
     * The unique id for this instance.
     */
    protected String checksumAppId;

    /**
     * The channel used for communication.
     */
    protected ChannelID theCR;

    /**
     * Method for closing.
     */
    abstract void close();
    
    /**
     * Method for cleaning up.
     */
    public abstract void cleanup();
    
    /**
     * Method for retrieving the application id.
     * 
     * @return The application id.
     */
    public abstract String getAppId();

    /**
     * Requiring all inheritors of this interface to handle the UploadMessage. 
     * The data should be fetched and put into the archive.
     * 
     * @param msg The UploadMessage to be handled.
     */
    public abstract void visit(UploadMessage msg);
    
    /**
     * Requiring all inheritors of this interface to handle the CorrectMessage. 
     * If an entry in the archive corresponds to the 'wrong' entry described in 
     * the CorrectMessage, then the file in the CorrectMessage should replace 
     * the current entry in the archive.
     * 
     * @param msg The CorrectMessage to be handled.
     */
    public abstract void visit(CorrectMessage msg);
    
    /**
     * Requiring all inheritors of this interface to handle the 
     * GetChecksumMessage. The checksum of the wanted entry in the  archive 
     * should be fetched and returned.
     * 
     * @param msg The GetChecksumMessage to be handled.
     */
    public abstract void visit(GetChecksumMessage msg);
    
    /**
     * Requiring all inheritors of this interface to handle the 
     * GetAllChecksumMessage. The entire archive should be put into a file 
     * corresponding to a ChecksumJob file, then made into a remote file and 
     * sent back through the reply.
     * 
     * @param msg The GetAllChecksumMessage to be handled.
     */
    public abstract void visit(GetAllChecksumsMessage msg);
    
    /**
     * Requiring all inheritors of this interface to handle the 
     * GetAllFilenamesMessage. The filenames of all the entries in the archive 
     * should be placed in a file corresponding to a FilelistJob and sent back 
     * through the reply.
     * 
     * @param msg The GetAllFilenamesMessage to be handled.
     */
    public abstract void visit(GetAllFilenamesMessage msg);
}
