import java.io.File;
import java.io.FileNotFoundException;

import dk.netarkivet.common.utils.FileUtils;
import dk.netarkivet.viewerproxy.webinterface.Reporting;


public class ExtractCrawlogForSpecificDomainAndJobId {

    /**
     * @param args A resultfile generated by the tool FindDomainsForCrawllogExtraction
     * @throws FileNotFoundException 
     */
    public static void main(String[] args) throws FileNotFoundException {
        if (args.length != 2) {
            System.err.println("Missing argument: ExtractCrawlogsForSpecificDomains domainName jobID");
            System.exit(1);
        }
        String domainName = args[0];

        int jobID = 0;
        try {
            jobID = Integer.parseInt(args[1]);
            if (jobID <= 0) {
                System.err.println("The given jobID value '" + jobID 
                        + "' is not a positive integer");
                System.exit(1);
            }
        } catch (NumberFormatException e){
            System.err.println("The given jobID value '" + args[1] 
                    + "' could not be identified as a positive integer.");
            System.exit(1);
        }

        String nameSuffix = "_crawlog.txt";
        String msgpart = "crawl-log for domain: " + domainName + "and jobID " + jobID;
        System.out.println("Fetching " + msgpart); 

        File result = Reporting.getCrawlLogForDomainInJob(domainName, jobID);
        if (result != null && result.length() > 0) {
            // Copy data to file domainname_jobid_crawlog.txt
            File outputFile = new File(domainName + "_" + jobID + nameSuffix);
            FileUtils.copyFile(result, outputFile);
            System.out.println("Data with " + msgpart + " successfully retrieved and copied to file");
        } else {
            System.err.println("No data received for domain '" + domainName 
                    + "' from result of harvest job '" + jobID + "'");
        }
    }

}
